.. _header-n0:

jspcap
======

 The ``jspcap`` project is an open source Python program focus on
`PCAP <https://en.wikipedia.org/wiki/Pcap>`__ parsing and analysis,
which works as a stream pcap file extractor. With support of
```jsformat`` <https://github.com/JarryShaw/jsformat>`__, it shall
support multiple output report formats.

 Notice that the whole project only supports **Python 3.6** or later.
